import { Kafka, KafkaMessage } from 'kafkajs';
import TypedEmitter from 'typed-emitter';
import { SagaContext, Saga, ILoggerConfig, Middleware, IEffectDescription, ITopicSagaConsumerConfig, IConsumptionEvent } from './types';
import { TopicAdministrator } from './topic_administrator';
export declare class TopicSagaConsumer<Payload, Context extends Record<string, any> = Record<string, any>> {
    eventEmitter: TypedEmitter<{
        comitted_offsets: (...args: any[]) => void;
        started_saga: (...args: any[]) => void;
        completed_saga: (...args: any[]) => void;
        consumed_message: (consumptionEvent: IConsumptionEvent<Payload>) => void;
    }>;
    private config;
    private consumer;
    private saga;
    private topic;
    private getContext;
    private logger;
    private middlewares;
    private topicAdminstrator;
    private consumerPool;
    private throttledProducer;
    private backgroundHeartbeat?;
    constructor({ kafka, topic, saga, getContext, loggerConfig, middlewares, config, topicAdministrator }: {
        kafka: Kafka;
        topic: string;
        saga: Saga<Payload, SagaContext<Context>>;
        config?: Partial<ITopicSagaConsumerConfig>;
        getContext?: (message: KafkaMessage) => Promise<Context>;
        topicAdministrator?: TopicAdministrator;
        loggerConfig?: ILoggerConfig;
        middlewares?: Array<Middleware<IEffectDescription, SagaContext<Context>>>;
    });
    /**
     * Catching and crashing is left to consumers of this class
     * so that they can log as they see fit.
     */
    run(): Promise<void>;
    disconnect(): Promise<void>;
    private eachMessage;
}
